@@ -23,22 +23,22 @@
 
 #include "denemo_types.h"
 
-void dnm_insertchord (DenemoGUI  *gui, gint duration, input_mode mode, 
+void dnm_insertchord (DenemoProject  *gui, gint duration, input_mode mode, 
 		      gboolean rest);
-void dnm_insertmeasures (DenemoScore  *si, gint number);
-void dnm_deleteobject (DenemoScore *si);
-void dnm_deletemeasure (DenemoScore *si);
+void dnm_insertmeasures (DenemoMovement  *si, gint number);
+void dnm_deleteobject (DenemoMovement *si);
+void dnm_deletemeasure (DenemoMovement *si);
 
 
 void dnm_addornament(DenemoObject *obj, Ornament orn);
 void 
-dnm_setinitialclef(DenemoScore *si, DenemoStaff *curstaffstruct, 
+dnm_setinitialclef(DenemoMovement *si, DenemoStaff *curstaffstruct, 
 		   enum clefs clef);
 void 
-dnm_setinitialtimesig (DenemoScore *si, DenemoStaff * curstaffstruct, 
+dnm_setinitialtimesig (DenemoMovement *si, DenemoStaff * curstaffstruct, 
 		       gint time1,gint time2, gboolean all_staves);
 void
-dnm_insert_timesig (DenemoScore * si, DenemoStaff * curstaffstruct, gint time1, gint time2);
+dnm_insert_timesig (DenemoMovement * si, DenemoStaff * curstaffstruct, gint time1, gint time2);
 
 void dnm_setinitialkeysig(DenemoStaff *curstaff, gint tokey, gint type);
 void dnm_set_denemo_name (GString *lily_name, GString *denemo_name);
@@ -48,7 +48,7 @@ void dnm_set_denemo_name (GString *lily_name, GString *denemo_name);
 
 void dnm_addtone (DenemoObject * thechord, gint mid_c_offset, gint enshift, gint dclef);
 DenemoObject * dnm_newchord (gint baseduration, gint numdots, int tied);
-measurenode * dnm_addmeasures (DenemoScore * si, gint pos, guint nummeasures, gint all);
+measurenode * dnm_addmeasures (DenemoMovement * si, gint pos, guint nummeasures, gint all);
 /* create one DenemoObject of type not known to denemo otherwise 
 *  no object is associated. */
 
