@@ -430,10 +430,11 @@ typedef struct DenemoPrefs
   gint pitchspellingprogram; /**< program to set pitchspellingchannel to on startup */
   gboolean startmidiin; /**< try to start midi in on startup */
   gboolean applytoselection; /**< apply commands to selection */
+  
   gboolean quickshortcuts;/**< TRUE if pressing a key while hovering over a menu item sets a shortcut */
   gboolean overlays; /*< whether overlays or insert should be used with pitch entry */
   gboolean continuous; /*< whether pitch entry overlays should cross barlines */
-  gboolean lilyentrystyle;  
+  gboolean spillover;  /*< whether appending a note that does not fit the measure should cause a spillover to the next measure */
   gboolean createclones;
   gint mode; /**< mode to start in */
   gboolean persistence;/**< whether Denemo should re-use settings over sessions */
@@ -698,19 +699,6 @@ typedef struct DenemoUndoData
 } DenemoUndoData;
  
 
-/**
- * Structure to hold bookmark information
- * Id - gint
- * Bar - gint
- * Staff - gint
- */
-typedef struct Bookmark
-{
-  gint id;
-  gint bar;
-  gint staff;
-}Bookmark;
-
 /** 
  * Control of the LilyPond output for the whole musical score DenemoProject
  *
@@ -952,8 +940,6 @@ typedef struct DenemoMovement
   
 
  
-  GList *bookmarks;
-  gint currentbookmark;
   GList *Instruments;
   GtkWidget *buttonbox;/*< box for buttons accessing DenemoDirectives attached to the this movement*/
   GtkWidget *lyricsbox;/*< box for notebooks containing verses of lyrics for the movement */
@@ -1133,7 +1119,9 @@ struct DenemoRoot
   GList *continuations;
   struct RhythmPattern *singleton_rhythms[256]; /**< rhythm patterns for the EntryToolbar */
   gboolean ScriptRecording;/**< TRUE when menuitems presses are being recorded as scheme script*/
-  gint keyboard_state;/**< state of last keypress/release */
+  gint keyboard_state;/**< state of last keypress/release controlling MIDI in*/
+  gboolean keyboard_state_locked;/**< lock against changes by shift and control keypresses */
+
   GtkWidget *ScriptView; /**< a GtkTextView containing a scheme script */
   GList *palettes; /**< list of palettes of buttons for activating scripts */
   gchar *old_user_data_dir; /**< set in case of upgrading denemo version */
