@@ -107,7 +107,7 @@ struct name_and_function denemo_commands[] = {
   {NULL, "Reduce the dotting of the chord note or rest at the cursor.", N_("RemoveDot"), "remove_dot_key", N_("Remove Dot")},
 
   {NULL, "Inserts a duplicate of the current note, tied", N_("InsertTiedNote"), "tie_notes_key", "Tied note"},
-  {NULL, "Ties/unties the note at the cursor", N_("ToggleTie"), "toggle_tie", "Toggle Tie"},
+  {NULL, "Ties/unties the note at the cursorm. The following note should be the same pitch.", N_("ToggleTie"), "toggle_tie", "Tie (Off/On)"},
 
   {NULL, "Delete the object at the cursor", N_("DeleteObject"), "deleteobject", N_("Delete Object")},
   {NULL, "Delete to the left of the cursor.", N_("DeletePreviousObject"), "deletepreviousobject", N_("Delete Previous Object")},
@@ -233,8 +233,8 @@ struct name_and_function denemo_commands[] = {
   {NULL, "Sets the start point for a selection,\\nthe end point of the selection is unaltered", N_("SetMark"), "set_mark", N_("Set Mark")},
   {NULL, "Gets rid of the selection.", N_("UnsetMark"), "unset_mark", N_("Unset Mark")},
   {NULL, "Extends the selection to the current cursor position", N_("SetPoint"), "set_point", N_("Set Point")},
-  {NULL, "Insert/delete begin slur on this note", N_("ToggleBeginSlur"), "toggle_begin_slur", N_("Begin Slur")},
-  {NULL, "Insert/delete end slur on this note", N_("ToggleEndSlur"), "toggle_end_slur", N_("End Slur")},
+  {NULL, "Insert/delete begin slur on this note", N_("ToggleBeginSlur"), "toggle_begin_slur", N_("Begin Slur (Off/On)")},
+  {NULL, "Insert/delete end slur on this note", N_("ToggleEndSlur"), "toggle_end_slur", N_("End Slur (Off/On)")},
 
   {NULL, "Marks/Unmarks the chord or note at the cursor as the start of a crescendo.", N_("ToggleStartCrescendo"), "toggle_start_crescendo", N_("Start Crescendo (Off/On)")},
   {NULL, "Marks/Unmarks the chord or note at the cursor as the end of a crescendo.", N_("ToggleEndCrescendo"), "toggle_end_crescendo", N_("End Crescendo (Off/On)")},
@@ -262,6 +262,7 @@ struct name_and_function denemo_commands[] = {
   {NULL, "Different keyboard and MIDI entry modes", N_("ModeMenu"), NULL, "Mode"},
   {NULL, "Menu:\\nGeneral editing commands", N_("EditMenu"), NULL, "Edit"},
   {NULL, "Menu:\\nControl which tools are to be shown", N_("ViewMenu"), NULL, "View"},
+  {NULL, "Menu:\\nHidden Items", N_("HiddenMenu"), NULL, "Hidden"},
 
   {NULL, "Menu:\\nCommands that manipulate Staffs and voices on staffs.\\nCommands that apply to the current staff.", N_("StaffMenu"), NULL, "Staffs/Voices"},
   {NULL, "Menu:\\nCommands for properties of the current staff.", N_("StaffPropertiesMenu"), NULL, "Staff Properties"},
@@ -370,7 +371,6 @@ struct name_and_function denemo_commands[] = {
   {NULL, "Hide the figured bass on the current staff on printing", N_("HideFiguredBass"), "hide_figured_bass", "Hide Figures (Print)"},
   {NULL, "Show the figured bass on the current staff on printing", N_("ShowFiguredBass"), "show_figured_bass", "Show Figures (Print)"},
   {NULL, "Allows chord symbols to be added to the current note. E.G.cis:dim7 for c-sharp diminished 7th. See Lilypond docs for notation", N_("EditChords"), "fakechord_insert", N_("Edit Chord Symbols")},
-  {NULL, "Inserts a dynamic marking at the cursor position", N_("InsertDynamic"), "insert_dynamic", N_("Insert Dynamics")},
 
   {NULL, "Edit the object at the cursor.", N_("EditObject"), "edit_object", N_("Edit Object")},
 
@@ -390,7 +390,6 @@ struct name_and_function denemo_commands[] = {
 
   {NULL, "Attach or edit attached LilyPond text to the note at the cursor. This can be used for guitar fingerings, cautionary accidentals and much more. See LilyPond documentation.", N_("AttachLilyToNote"), "note_directive", N_("Attach Lilypond to Note")},
   {NULL, "Attach or edit attached LilyPond text to the chord at the cursor. This can be used for attaching and placing text and much more. See LilyPond documentation.", N_("AttachLilyToChord"), "chord_directive", N_("Attach Lilypond to Chord")},
-  {NULL, "Inserts specialized barline at the cursor position. Mostly not working", N_("InsertBarline"), "insert_barline", N_("Insert Barline")},
   {NULL, "Moving the cursor within the current movement, setting bookmarks, seeking things in the score", N_("NavigationMenu"), NULL, "Navigation"},
   {NULL, "Opens a dialog for going to a numbered measure", N_("GoToMeasure"), "tomeasurenum", "Go to Measure"},
   {"GTK_STOCK_GOTO_FIRST", "Cursor to start of staff/voice, extending selection if any", N_("GoToBeginning"), "tohome", "Go to Beginning"},
@@ -415,6 +414,7 @@ struct name_and_function denemo_commands[] = {
 
   {NULL, "Opens a browser on the user manual", N_("Help"), "browse_manual", N_("Browse Manual")},
   {NULL, "Gives the version number etc of this program", N_("About"), "about", N_("About")},
+  {NULL, "Gives a list of shortcuts currently available. Explains how to set them too.", N_("Shortcuts"), "display_shortcuts", N_("Shortcuts")},
 
 
   {NULL, "Allows choosing extra commands/menu items from disk", N_("MoreMenu"), NULL, N_("More")},
@@ -539,6 +539,7 @@ struct name_and_function denemo_commands[] = {
   {NULL, "Menu:\\nCommands to manipulate the palettes of commands", N_("Palettes"), NULL, N_("Palettes")},
   {NULL, "Menu:\\nCommands to tell the typesetter to start or stop a particular effect. Use these around passages that are to be treated differently, or over which a marking should be placed.", N_("Spanning"), NULL, N_("Spanning")},
   {NULL, "Menu:\\nInstructions for the typesetter to do something at the cursor position.", N_("Typesetter"), NULL, N_("Typesetter")},
+  {NULL, "Menu:\\nInstructions for the typesetter to combine two voices in various ways.", N_("Part-Combining"), NULL, N_("Part-Combining")},
 
   {NULL, "Menu:\\nCommands for working with the musical object hierarchy.", N_("ObjectMenu"), NULL, N_("Object Menu")},
   {NULL, "Menu:\\nThe top level commands for operating Denemo.", N_("MainMenu"), NULL, N_("Main Menu")},
